@@ -338,7 +338,8 @@ class Cleanup(Blueprint):
     def _get_replicated_lambda_state_machine_role(self,
                                                   remover_function,  # type: Dict[str, Union[awslambda.Function, iam.Role, Any]] # noqa pylint: disable=line-too-long
                                                   self_destruct_function # type: Dict[str, Union[awslambda.Function, iam.Role, Any]] # noqa pylint: disable=line-too-long
-                                                 ):
+                                                  # TODO remove after dropping python 2
+                                                  ):  # pylint: disable=bad-continuation
         # type (...) -> iam.Role
         variables = self.get_variables()
         entity = Join('.', ['states', Region, 'amazonaws.com'])
